"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_attributes_to_findings(findingArns=None, attributes=None):
    """
    :param findingArns: [REQUIRED]
            The ARNs that specify the findings that you want to assign attributes to.
            (string) --
            
    :type findingArns: list
    :param attributes: [REQUIRED]
            The array of attributes that you want to assign to specified findings.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            
    :type attributes: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_assessment_target(assessmentTargetName=None, resourceGroupArn=None):
    """
    :param assessmentTargetName: [REQUIRED]
            The user-defined name that identifies the assessment target that you want to create. The name must be unique within the AWS account.
            
    :type assessmentTargetName: string
    :param resourceGroupArn: [REQUIRED]
            The ARN that specifies the resource group that is used to create the assessment target.
            
    :type resourceGroupArn: string
    """
    pass

def create_assessment_template(assessmentTargetArn=None, assessmentTemplateName=None, durationInSeconds=None, rulesPackageArns=None, userAttributesForFindings=None):
    """
    :param assessmentTargetArn: [REQUIRED]
            The ARN that specifies the assessment target for which you want to create the assessment template.
            
    :type assessmentTargetArn: string
    :param assessmentTemplateName: [REQUIRED]
            The user-defined name that identifies the assessment template that you want to create. You can create several assessment templates for an assessment target. The names of the assessment templates that correspond to a particular assessment target must be unique.
            
    :type assessmentTemplateName: string
    :param durationInSeconds: [REQUIRED]
            The duration of the assessment run in seconds. The default value is 3600 seconds (one hour).
            
    :type durationInSeconds: integer
    :param rulesPackageArns: [REQUIRED]
            The ARNs that specify the rules packages that you want to attach to the assessment template.
            (string) --
            
    :type rulesPackageArns: list
    :param userAttributesForFindings: The user-defined attributes that are assigned to every finding that is generated by the assessment run that uses this assessment template.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            
    :type userAttributesForFindings: list
    """
    pass

def create_resource_group(resourceGroupTags=None):
    """
    :param resourceGroupTags: [REQUIRED]
            A collection of keys and an array of possible values, '[{'key':'key1','values':['Value1','Value2']},{'key':'Key2','values':['Value3']}]'.
            For example,'[{'key':'Name','values':['TestEC2Instance']}]'.
            (dict) --This data type is used as one of the elements of the ResourceGroup data type.
            key (string) -- [REQUIRED]A tag key.
            value (string) --The value assigned to a tag key.
            
            Return typedict
            ReturnsResponse Syntax{
              'resourceGroupArn': 'string'
            }
            Response Structure
            (dict) --
            resourceGroupArn (string) --The ARN that specifies the resource group that is created.
            
            
    :type resourceGroupTags: list
    """
    pass

def delete_assessment_run(assessmentRunArn=None):
    """
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run that you want to delete.
            ReturnsNone
            
    :type assessmentRunArn: string
    """
    pass

def delete_assessment_target(assessmentTargetArn=None):
    """
    :param assessmentTargetArn: [REQUIRED]
            The ARN that specifies the assessment target that you want to delete.
            ReturnsNone
            
    :type assessmentTargetArn: string
    """
    pass

def delete_assessment_template(assessmentTemplateArn=None):
    """
    :param assessmentTemplateArn: [REQUIRED]
            The ARN that specifies the assessment template that you want to delete.
            ReturnsNone
            
    :type assessmentTemplateArn: string
    """
    pass

def describe_assessment_runs(assessmentRunArns=None):
    """
    :param assessmentRunArns: [REQUIRED]
            The ARN that specifies the assessment run that you want to describe.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'assessmentRuns': [
                {
                  'arn': 'string',
                  'name': 'string',
                  'assessmentTemplateArn': 'string',
                  'state': 'CREATED'|'START_DATA_COLLECTION_PENDING'|'START_DATA_COLLECTION_IN_PROGRESS'|'COLLECTING_DATA'|'STOP_DATA_COLLECTION_PENDING'|'DATA_COLLECTED'|'EVALUATING_RULES'|'FAILED'|'COMPLETED'|'COMPLETED_WITH_ERRORS',
                  'durationInSeconds': 123,
                  'rulesPackageArns': [
                    'string',
                  ],
                  'userAttributesForFindings': [
                    {
                      'key': 'string',
                      'value': 'string'
                    },
                  ],
                  'createdAt': datetime(2015, 1, 1),
                  'startedAt': datetime(2015, 1, 1),
                  'completedAt': datetime(2015, 1, 1),
                  'stateChangedAt': datetime(2015, 1, 1),
                  'dataCollected': True|False,
                  'stateChanges': [
                    {
                      'stateChangedAt': datetime(2015, 1, 1),
                      'state': 'CREATED'|'START_DATA_COLLECTION_PENDING'|'START_DATA_COLLECTION_IN_PROGRESS'|'COLLECTING_DATA'|'STOP_DATA_COLLECTION_PENDING'|'DATA_COLLECTED'|'EVALUATING_RULES'|'FAILED'|'COMPLETED'|'COMPLETED_WITH_ERRORS'
                    },
                  ],
                  'notifications': [
                    {
                      'date': datetime(2015, 1, 1),
                      'event': 'ASSESSMENT_RUN_STARTED'|'ASSESSMENT_RUN_COMPLETED'|'ASSESSMENT_RUN_STATE_CHANGED'|'FINDING_REPORTED'|'OTHER',
                      'message': 'string',
                      'error': True|False,
                      'snsTopicArn': 'string',
                      'snsPublishStatusCode': 'SUCCESS'|'TOPIC_DOES_NOT_EXIST'|'ACCESS_DENIED'|'INTERNAL_ERROR'
                    },
                  ]
                },
              ],
              'failedItems': {
                'string': {
                  'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                  'retryable': True|False
                }
              }
            }
            Response Structure
            (dict) --
            assessmentRuns (list) --Information about the assessment run.
            (dict) --A snapshot of an Amazon Inspector assessment run that contains the findings of the assessment run .
            Used as the response element in the DescribeAssessmentRuns action.
            arn (string) --The ARN of the assessment run.
            name (string) --The auto-generated name for the assessment run.
            assessmentTemplateArn (string) --The ARN of the assessment template that is associated with the assessment run.
            state (string) --The state of the assessment run.
            durationInSeconds (integer) --The duration of the assessment run.
            rulesPackageArns (list) --The rules packages selected for the assessment run.
            (string) --
            userAttributesForFindings (list) --The user-defined attributes that are assigned to every generated finding.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) --The attribute key.
            value (string) --The value assigned to the attribute key.
            
            createdAt (datetime) --The time when StartAssessmentRun was called.
            startedAt (datetime) --The time when StartAssessmentRun was called.
            completedAt (datetime) --The assessment run completion time that corresponds to the rules packages evaluation completion time or failure.
            stateChangedAt (datetime) --The last time when the assessment run's state changed.
            dataCollected (boolean) --A Boolean value (true or false) that specifies whether the process of collecting data from the agents is completed.
            stateChanges (list) --A list of the assessment run state changes.
            (dict) --Used as one of the elements of the AssessmentRun data type.
            stateChangedAt (datetime) --The last time the assessment run state changed.
            state (string) --The assessment run state.
            
            notifications (list) --A list of notifications for the event subscriptions. A notification about a particular generated finding is added to this list only once.
            (dict) --Used as one of the elements of the AssessmentRun data type.
            date (datetime) --The date of the notification.
            event (string) --The event for which a notification is sent.
            message (string) --
            error (boolean) --The Boolean value that specifies whether the notification represents an error.
            snsTopicArn (string) --The SNS topic to which the SNS notification is sent.
            snsPublishStatusCode (string) --The status code of the SNS notification.
            
            
            failedItems (dict) --Assessment run details that cannot be described. An error code is provided for each failed item.
            (string) --
            (dict) --Includes details about the failed items.
            failureCode (string) --The status code of a failed item.
            retryable (boolean) --Indicates whether you can immediately retry a request for this item for a specified resource.
            
            
            
            
    :type assessmentRunArns: list
    """
    pass

def describe_assessment_targets(assessmentTargetArns=None):
    """
    :param assessmentTargetArns: [REQUIRED]
            The ARNs that specifies the assessment targets that you want to describe.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'assessmentTargets': [
                {
                  'arn': 'string',
                  'name': 'string',
                  'resourceGroupArn': 'string',
                  'createdAt': datetime(2015, 1, 1),
                  'updatedAt': datetime(2015, 1, 1)
                },
              ],
              'failedItems': {
                'string': {
                  'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                  'retryable': True|False
                }
              }
            }
            Response Structure
            (dict) --
            assessmentTargets (list) --Information about the assessment targets.
            (dict) --Contains information about an Amazon Inspector application. This data type is used as the response element in the DescribeAssessmentTargets action.
            arn (string) --The ARN that specifies the Amazon Inspector assessment target.
            name (string) --The name of the Amazon Inspector assessment target.
            resourceGroupArn (string) --The ARN that specifies the resource group that is associated with the assessment target.
            createdAt (datetime) --The time at which the assessment target is created.
            updatedAt (datetime) --The time at which UpdateAssessmentTarget is called.
            
            failedItems (dict) --Assessment target details that cannot be described. An error code is provided for each failed item.
            (string) --
            (dict) --Includes details about the failed items.
            failureCode (string) --The status code of a failed item.
            retryable (boolean) --Indicates whether you can immediately retry a request for this item for a specified resource.
            
            
            
            
    :type assessmentTargetArns: list
    """
    pass

def describe_assessment_templates(assessmentTemplateArns=None):
    """
    :param assessmentTemplateArns: [REQUIRED]
            The ARN that specifiesthe assessment templates that you want to describe.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'assessmentTemplates': [
                {
                  'arn': 'string',
                  'name': 'string',
                  'assessmentTargetArn': 'string',
                  'durationInSeconds': 123,
                  'rulesPackageArns': [
                    'string',
                  ],
                  'userAttributesForFindings': [
                    {
                      'key': 'string',
                      'value': 'string'
                    },
                  ],
                  'createdAt': datetime(2015, 1, 1)
                },
              ],
              'failedItems': {
                'string': {
                  'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                  'retryable': True|False
                }
              }
            }
            Response Structure
            (dict) --
            assessmentTemplates (list) --Information about the assessment templates.
            (dict) --Contains information about an Amazon Inspector assessment template. This data type is used as the response element in the DescribeAssessmentTemplates action.
            arn (string) --The ARN of the assessment template.
            name (string) --The name of the assessment template.
            assessmentTargetArn (string) --The ARN of the assessment target that corresponds to this assessment template.
            durationInSeconds (integer) --The duration in seconds specified for this assessment tempate. The default value is 3600 seconds (one hour). The maximum value is 86400 seconds (one day).
            rulesPackageArns (list) --The rules packages that are specified for this assessment template.
            (string) --
            userAttributesForFindings (list) --The user-defined attributes that are assigned to every generated finding from the assessment run that uses this assessment template.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) --The attribute key.
            value (string) --The value assigned to the attribute key.
            
            createdAt (datetime) --The time at which the assessment template is created.
            
            failedItems (dict) --Assessment template details that cannot be described. An error code is provided for each failed item.
            (string) --
            (dict) --Includes details about the failed items.
            failureCode (string) --The status code of a failed item.
            retryable (boolean) --Indicates whether you can immediately retry a request for this item for a specified resource.
            
            
            
            
    :type assessmentTemplateArns: list
    """
    pass

def describe_cross_account_access_role():
    """
    """
    pass

def describe_findings(findingArns=None, locale=None):
    """
    :param findingArns: [REQUIRED]
            The ARN that specifies the finding that you want to describe.
            (string) --
            
    :type findingArns: list
    :param locale: The locale into which you want to translate a finding description, recommendation, and the short description that identifies the finding.
    :type locale: string
    """
    pass

def describe_resource_groups(resourceGroupArns=None):
    """
    :param resourceGroupArns: [REQUIRED]
            The ARN that specifies the resource group that you want to describe.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'resourceGroups': [
                {
                  'arn': 'string',
                  'tags': [
                    {
                      'key': 'string',
                      'value': 'string'
                    },
                  ],
                  'createdAt': datetime(2015, 1, 1)
                },
              ],
              'failedItems': {
                'string': {
                  'failureCode': 'INVALID_ARN'|'DUPLICATE_ARN'|'ITEM_DOES_NOT_EXIST'|'ACCESS_DENIED'|'LIMIT_EXCEEDED'|'INTERNAL_ERROR',
                  'retryable': True|False
                }
              }
            }
            Response Structure
            (dict) --
            resourceGroups (list) --Information about a resource group.
            (dict) --Contains information about a resource group. The resource group defines a set of tags that, when queried, identify the AWS resources that make up the assessment target. This data type is used as the response element in the DescribeResourceGroups action.
            arn (string) --The ARN of the resource group.
            tags (list) --The tags (key and value pairs) of the resource group. This data type property is used in the CreateResourceGroup action.
            (dict) --This data type is used as one of the elements of the ResourceGroup data type.
            key (string) --A tag key.
            value (string) --The value assigned to a tag key.
            
            createdAt (datetime) --The time at which resource group is created.
            
            failedItems (dict) --Resource group details that cannot be described. An error code is provided for each failed item.
            (string) --
            (dict) --Includes details about the failed items.
            failureCode (string) --The status code of a failed item.
            retryable (boolean) --Indicates whether you can immediately retry a request for this item for a specified resource.
            
            
            
            
    :type resourceGroupArns: list
    """
    pass

def describe_rules_packages(rulesPackageArns=None, locale=None):
    """
    :param rulesPackageArns: [REQUIRED]
            The ARN that specifies the rules package that you want to describe.
            (string) --
            
    :type rulesPackageArns: list
    :param locale: The locale that you want to translate a rules package description into.
    :type locale: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_telemetry_metadata(assessmentRunArn=None):
    """
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run that has the telemetry data that you want to obtain.
            Return typedict
            ReturnsResponse Syntax{
              'telemetryMetadata': [
                {
                  'messageType': 'string',
                  'count': 123,
                  'dataSize': 123
                },
              ]
            }
            Response Structure
            (dict) --
            telemetryMetadata (list) --Telemetry details.
            (dict) --The metadata about the Amazon Inspector application data metrics collected by the agent. This data type is used as the response element in the GetTelemetryMetadata action.
            messageType (string) --A specific type of behavioral data that is collected by the agent.
            count (integer) --The count of messages that the agent sends to the Amazon Inspector service.
            dataSize (integer) --The data size of messages that the agent sends to the Amazon Inspector service.
            
            
            
    :type assessmentRunArn: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_assessment_run_agents(assessmentRunArn=None, filter=None, nextToken=None, maxResults=None):
    """
    :param assessmentRunArn: [REQUIRED]
            The ARN that specifies the assessment run whose agents you want to list.
            
    :type assessmentRunArn: string
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            agentHealths (list) -- [REQUIRED]The current health state of the agent. Values can be set to HEALTHY or UNHEALTHY .
            (string) --
            agentHealthCodes (list) -- [REQUIRED]The detailed health state of the agent. Values can be set to IDLE , RUNNING , SHUTDOWN , UNHEALTHY , THROTTLED , and UNKNOWN .
            (string) --
            
    :type filter: dict
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentRunAgents action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_assessment_runs(assessmentTemplateArns=None, filter=None, nextToken=None, maxResults=None):
    """
    :param assessmentTemplateArns: The ARNs that specify the assessment templates whose assessment runs you want to list.
            (string) --
            
    :type assessmentTemplateArns: list
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            namePattern (string) --For a record to match a filter, an explicit value or a string containing a wildcard that is specified for this data type property must match the value of the assessmentRunName property of the AssessmentRun data type.
            states (list) --For a record to match a filter, one of the values specified for this data type property must be the exact match of the value of the assessmentRunState property of the AssessmentRun data type.
            (string) --
            durationRange (dict) --For a record to match a filter, the value that is specified for this data type property must inclusively match any value between the specified minimum and maximum values of the durationInSeconds property of the AssessmentRun data type.
            minSeconds (integer) --The minimum value of the duration range. Must be greater than zero.
            maxSeconds (integer) --The maximum value of the duration range. Must be less than or equal to 604800 seconds (1 week).
            rulesPackageArns (list) --For a record to match a filter, the value that is specified for this data type property must be contained in the list of values of the rulesPackages property of the AssessmentRun data type.
            (string) --
            startTimeRange (dict) --For a record to match a filter, the value that is specified for this data type property must inclusively match any value between the specified minimum and maximum values of the startTime property of the AssessmentRun data type.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            completionTimeRange (dict) --For a record to match a filter, the value that is specified for this data type property must inclusively match any value between the specified minimum and maximum values of the completedAt property of the AssessmentRun data type.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            stateChangeTimeRange (dict) --For a record to match a filter, the value that is specified for this data type property must match the stateChangedAt property of the AssessmentRun data type.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            
            
    :type filter: dict
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentRuns action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_assessment_targets(filter=None, nextToken=None, maxResults=None):
    """
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            assessmentTargetNamePattern (string) --For a record to match a filter, an explicit value or a string that contains a wildcard that is specified for this data type property must match the value of the assessmentTargetName property of the AssessmentTarget data type.
            
    :type filter: dict
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentTargets action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_assessment_templates(assessmentTargetArns=None, filter=None, nextToken=None, maxResults=None):
    """
    :param assessmentTargetArns: A list of ARNs that specifies the assessment targets whose assessment templates you want to list.
            (string) --
            
    :type assessmentTargetArns: list
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            namePattern (string) --For a record to match a filter, an explicit value or a string that contains a wildcard that is specified for this data type property must match the value of the assessmentTemplateName property of the AssessmentTemplate data type.
            durationRange (dict) --For a record to match a filter, the value specified for this data type property must inclusively match any value between the specified minimum and maximum values of the durationInSeconds property of the AssessmentTemplate data type.
            minSeconds (integer) --The minimum value of the duration range. Must be greater than zero.
            maxSeconds (integer) --The maximum value of the duration range. Must be less than or equal to 604800 seconds (1 week).
            rulesPackageArns (list) --For a record to match a filter, the values that are specified for this data type property must be contained in the list of values of the rulesPackageArns property of the AssessmentTemplate data type.
            (string) --
            
    :type filter: dict
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentTemplates action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_event_subscriptions(resourceArn=None, nextToken=None, maxResults=None):
    """
    :param resourceArn: The ARN of the assessment template for which you want to list the existing event subscriptions.
    :type resourceArn: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListEventSubscriptions action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_findings(assessmentRunArns=None, filter=None, nextToken=None, maxResults=None):
    """
    :param assessmentRunArns: The ARNs of the assessment runs that generate the findings that you want to list.
            (string) --
            
    :type assessmentRunArns: list
    :param filter: You can use this parameter to specify a subset of data to be included in the action's response.
            For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match.
            agentIds (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the agentId property of the Finding data type.
            (string) --
            autoScalingGroups (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the autoScalingGroup property of the Finding data type.
            (string) --
            ruleNames (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the ruleName property of the Finding data type.
            (string) --
            severities (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the severity property of the Finding data type.
            (string) --
            rulesPackageArns (list) --For a record to match a filter, one of the values that is specified for this data type property must be the exact match of the value of the rulesPackageArn property of the Finding data type.
            (string) --
            attributes (list) --For a record to match a filter, the list of values that are specified for this data type property must be contained in the list of values of the attributes property of the Finding data type.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            userAttributes (list) --For a record to match a filter, the value that is specified for this data type property must be contained in the list of values of the userAttributes property of the Finding data type.
            (dict) --This data type is used as a request parameter in the AddAttributesToFindings and CreateAssessmentTemplate actions.
            key (string) -- [REQUIRED]The attribute key.
            value (string) --The value assigned to the attribute key.
            
            creationTimeRange (dict) --The time range during which the finding is generated.
            beginDate (datetime) --The minimum value of the timestamp range.
            endDate (datetime) --The maximum value of the timestamp range.
            
            
    :type filter: dict
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListFindings action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_rules_packages(nextToken=None, maxResults=None):
    """
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListRulesPackages action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def list_tags_for_resource(resourceArn=None):
    """
    :param resourceArn: [REQUIRED]
            The ARN that specifies the assessment template whose tags you want to list.
            Return typedict
            ReturnsResponse Syntax{
              'tags': [
                {
                  'key': 'string',
                  'value': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            tags (list) --A collection of key and value pairs.
            (dict) --A key and value pair. This data type is used as a request parameter in the SetTagsForResource action and a response element in the ListTagsForResource action.
            key (string) --A tag key.
            value (string) --A value assigned to a tag key.
            
            
            
    :type resourceArn: string
    """
    pass

def preview_agents(previewAgentsArn=None, nextToken=None, maxResults=None):
    """
    :param previewAgentsArn: [REQUIRED]
            The ARN of the assessment target whose agents you want to preview.
            
    :type previewAgentsArn: string
    :param nextToken: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the PreviewAgents action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
    :type nextToken: string
    :param maxResults: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500.
    :type maxResults: integer
    """
    pass

def register_cross_account_access_role(roleArn=None):
    """
    :param roleArn: [REQUIRED]
            The ARN of the IAM role that Amazon Inspector uses to list your EC2 instances during the assessment run or when you call the PreviewAgents action.
            ReturnsNone
            
    :type roleArn: string
    """
    pass

def remove_attributes_from_findings(findingArns=None, attributeKeys=None):
    """
    :param findingArns: [REQUIRED]
            The ARNs that specify the findings that you want to remove attributes from.
            (string) --
            
    :type findingArns: list
    :param attributeKeys: [REQUIRED]
            The array of attribute keys that you want to remove from specified findings.
            (string) --
            
    :type attributeKeys: list
    """
    pass

def set_tags_for_resource(resourceArn=None, tags=None):
    """
    :param resourceArn: [REQUIRED]
            The ARN of the assessment template that you want to set tags to.
            
    :type resourceArn: string
    :param tags: A collection of key and value pairs that you want to set to the assessment template.
            (dict) --A key and value pair. This data type is used as a request parameter in the SetTagsForResource action and a response element in the ListTagsForResource action.
            key (string) -- [REQUIRED]A tag key.
            value (string) --A value assigned to a tag key.
            
            
    :type tags: list
    """
    pass

def start_assessment_run(assessmentTemplateArn=None, assessmentRunName=None):
    """
    :param assessmentTemplateArn: [REQUIRED]
            The ARN of the assessment template of the assessment run that you want to start.
            
    :type assessmentTemplateArn: string
    :param assessmentRunName: You can specify the name for the assessment run, or you can use the auto-generated name that is based on the assessment template name. The name must be unique for the assessment template.
    :type assessmentRunName: string
    """
    pass

def stop_assessment_run(assessmentRunArn=None):
    """
    :param assessmentRunArn: [REQUIRED]
            The ARN of the assessment run that you want to stop.
            ReturnsNone
            
    :type assessmentRunArn: string
    """
    pass

def subscribe_to_event(resourceArn=None, event=None, topicArn=None):
    """
    :param resourceArn: [REQUIRED]
            The ARN of the assessment template that is used during the event for which you want to receive SNS notifications.
            
    :type resourceArn: string
    :param event: [REQUIRED]
            The event for which you want to receive SNS notifications.
            
    :type event: string
    :param topicArn: [REQUIRED]
            The ARN of the SNS topic to which the SNS notifications are sent.
            
    :type topicArn: string
    """
    pass

def unsubscribe_from_event(resourceArn=None, event=None, topicArn=None):
    """
    :param resourceArn: [REQUIRED]
            The ARN of the assessment template that is used during the event for which you want to stop receiving SNS notifications.
            
    :type resourceArn: string
    :param event: [REQUIRED]
            The event for which you want to stop receiving SNS notifications.
            
    :type event: string
    :param topicArn: [REQUIRED]
            The ARN of the SNS topic to which SNS notifications are sent.
            
    :type topicArn: string
    """
    pass

def update_assessment_target(assessmentTargetArn=None, assessmentTargetName=None, resourceGroupArn=None):
    """
    :param assessmentTargetArn: [REQUIRED]
            The ARN of the assessment target that you want to update.
            
    :type assessmentTargetArn: string
    :param assessmentTargetName: [REQUIRED]
            The name of the assessment target that you want to update.
            
    :type assessmentTargetName: string
    :param resourceGroupArn: [REQUIRED]
            The ARN of the resource group that is used to specify the new resource group to associate with the assessment target.
            
    :type resourceGroupArn: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_tags(ResourceId=None, TagsList=None):
    """
    :param ResourceId: [REQUIRED]
            Specifies the ARN of the trail to which one or more tags will be added. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            
    :type ResourceId: string
    :param TagsList: Contains a list of CloudTrail tags, up to a limit of 10.
            (dict) --A custom key-value pair associated with a resource such as a CloudTrail trail.
            Key (string) -- [REQUIRED]The key in a key-value pair. The key must be must be no longer than 128 Unicode characters. The key must be unique for the resource to which it applies.
            Value (string) --The value in a key-value pair of a tag. The value must be no longer than 256 Unicode characters.
            
            
    :type TagsList: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_trail(Name=None, S3BucketName=None, S3KeyPrefix=None, SnsTopicName=None, IncludeGlobalServiceEvents=None, IsMultiRegionTrail=None, EnableLogFileValidation=None, CloudWatchLogsLogGroupArn=None, CloudWatchLogsRoleArn=None, KmsKeyId=None):
    """
    :param Name: [REQUIRED]
            Specifies the name of the trail. The name must meet the following requirements:
            Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)
            Start with a letter or number, and end with a letter or number
            Be between 3 and 128 characters
            Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are invalid.
            Not be in IP address format (for example, 192.168.5.4)
            
    :type Name: string
    :param S3BucketName: [REQUIRED]
            Specifies the name of the Amazon S3 bucket designated for publishing log files. See Amazon S3 Bucket Naming Requirements .
            
    :type S3BucketName: string
    :param S3KeyPrefix: Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files . The maximum length is 200 characters.
    :type S3KeyPrefix: string
    :param SnsTopicName: Specifies the name of the Amazon SNS topic defined for notification of log file delivery. The maximum length is 256 characters.
    :type SnsTopicName: string
    :param IncludeGlobalServiceEvents: Specifies whether the trail is publishing events from global services such as IAM to the log files.
    :type IncludeGlobalServiceEvents: boolean
    :param IsMultiRegionTrail: Specifies whether the trail is created in the current region or in all regions. The default is false.
    :type IsMultiRegionTrail: boolean
    :param EnableLogFileValidation: Specifies whether log file integrity validation is enabled. The default is false.
            Note
            When you disable log file integrity validation, the chain of digest files is broken after one hour. CloudTrail will not create digest files for log files that were delivered during a period in which log file integrity validation was disabled. For example, if you enable log file integrity validation at noon on January 1, disable it at noon on January 2, and re-enable it at noon on January 10, digest files will not be created for the log files delivered from noon on January 2 to noon on January 10. The same applies whenever you stop CloudTrail logging or delete a trail.
            
    :type EnableLogFileValidation: boolean
    :param CloudWatchLogsLogGroupArn: Specifies a log group name using an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered. Not required unless you specify CloudWatchLogsRoleArn.
    :type CloudWatchLogsLogGroupArn: string
    :param CloudWatchLogsRoleArn: Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group.
    :type CloudWatchLogsRoleArn: string
    :param KmsKeyId: Specifies the KMS key ID to use to encrypt the logs delivered by CloudTrail. The value can be a an alias name prefixed by 'alias/', a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier.
            Examples:
            alias/MyAliasName
            arn:aws:kms:us-east-1:123456789012:alias/MyAliasName
            arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012
            12345678-1234-1234-1234-123456789012
            
    :type KmsKeyId: string
    """
    pass

def delete_trail(Name=None):
    """
    :param Name: [REQUIRED]
            Specifies the name or the CloudTrail ARN of the trail to be deleted. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Returns the objects or data listed below if successful. Otherwise, returns an error.
            
            
    :type Name: string
    """
    pass

def describe_trails(trailNameList=None, includeShadowTrails=None):
    """
    :param trailNameList: Specifies a list of trail names, trail ARNs, or both, of the trails to describe. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            If an empty list is specified, information for the trail in the current region is returned.
            If an empty list is specified and IncludeShadowTrails is false, then information for all trails in the current region is returned.
            If an empty list is specified and IncludeShadowTrails is null or true, then information for all trails in the current region and any associated shadow trails in other regions is returned.
            Note
            If one or more trail names are specified, information is returned only if the names match the names of trails belonging only to the current region. To return information about a trail in another region, you must specify its trail ARN.
            (string) --
            
    :type trailNameList: list
    :param includeShadowTrails: Specifies whether to include shadow trails in the response. A shadow trail is the replication in a region of a trail that was created in a different region. The default is true.
    :type includeShadowTrails: boolean
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_trail_status(Name=None):
    """
    :param Name: [REQUIRED]
            Specifies the name or the CloudTrail ARN of the trail for which you are requesting status. To get the status of a shadow trail (a replication of the trail in another region), you must specify its ARN. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            Return typedict
            ReturnsResponse Syntax{
              'IsLogging': True|False,
              'LatestDeliveryError': 'string',
              'LatestNotificationError': 'string',
              'LatestDeliveryTime': datetime(2015, 1, 1),
              'LatestNotificationTime': datetime(2015, 1, 1),
              'StartLoggingTime': datetime(2015, 1, 1),
              'StopLoggingTime': datetime(2015, 1, 1),
              'LatestCloudWatchLogsDeliveryError': 'string',
              'LatestCloudWatchLogsDeliveryTime': datetime(2015, 1, 1),
              'LatestDigestDeliveryTime': datetime(2015, 1, 1),
              'LatestDigestDeliveryError': 'string',
              'LatestDeliveryAttemptTime': 'string',
              'LatestNotificationAttemptTime': 'string',
              'LatestNotificationAttemptSucceeded': 'string',
              'LatestDeliveryAttemptSucceeded': 'string',
              'TimeLoggingStarted': 'string',
              'TimeLoggingStopped': 'string'
            }
            Response Structure
            (dict) --Returns the objects or data listed below if successful. Otherwise, returns an error.
            IsLogging (boolean) --Whether the CloudTrail is currently logging AWS API calls.
            LatestDeliveryError (string) --Displays any Amazon S3 error that CloudTrail encountered when attempting to deliver log files to the designated bucket. For more information see the topic Error Responses in the Amazon S3 API Reference.
            Note
            This error occurs only when there is a problem with the destination S3 bucket and will not occur for timeouts. To resolve the issue, create a new bucket and call UpdateTrail to specify the new bucket, or fix the existing objects so that CloudTrail can again write to the bucket.
            LatestNotificationError (string) --Displays any Amazon SNS error that CloudTrail encountered when attempting to send a notification. For more information about Amazon SNS errors, see the Amazon SNS Developer Guide .
            LatestDeliveryTime (datetime) --Specifies the date and time that CloudTrail last delivered log files to an account's Amazon S3 bucket.
            LatestNotificationTime (datetime) --Specifies the date and time of the most recent Amazon SNS notification that CloudTrail has written a new log file to an account's Amazon S3 bucket.
            StartLoggingTime (datetime) --Specifies the most recent date and time when CloudTrail started recording API calls for an AWS account.
            StopLoggingTime (datetime) --Specifies the most recent date and time when CloudTrail stopped recording API calls for an AWS account.
            LatestCloudWatchLogsDeliveryError (string) --Displays any CloudWatch Logs error that CloudTrail encountered when attempting to deliver logs to CloudWatch Logs.
            LatestCloudWatchLogsDeliveryTime (datetime) --Displays the most recent date and time when CloudTrail delivered logs to CloudWatch Logs.
            LatestDigestDeliveryTime (datetime) --Specifies the date and time that CloudTrail last delivered a digest file to an account's Amazon S3 bucket.
            LatestDigestDeliveryError (string) --Displays any Amazon S3 error that CloudTrail encountered when attempting to deliver a digest file to the designated bucket. For more information see the topic Error Responses in the Amazon S3 API Reference.
            Note
            This error occurs only when there is a problem with the destination S3 bucket and will not occur for timeouts. To resolve the issue, create a new bucket and call UpdateTrail to specify the new bucket, or fix the existing objects so that CloudTrail can again write to the bucket.
            LatestDeliveryAttemptTime (string) --This field is deprecated.
            LatestNotificationAttemptTime (string) --This field is deprecated.
            LatestNotificationAttemptSucceeded (string) --This field is deprecated.
            LatestDeliveryAttemptSucceeded (string) --This field is deprecated.
            TimeLoggingStarted (string) --This field is deprecated.
            TimeLoggingStopped (string) --This field is deprecated.
            
            
    :type Name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_public_keys(StartTime=None, EndTime=None, NextToken=None):
    """
    :param StartTime: Optionally specifies, in UTC, the start of the time range to look up public keys for CloudTrail digest files. If not specified, the current time is used, and the current public key is returned.
    :type StartTime: datetime
    :param EndTime: Optionally specifies, in UTC, the end of the time range to look up public keys for CloudTrail digest files. If not specified, the current time is used.
    :type EndTime: datetime
    :param NextToken: Reserved for future use.
    :type NextToken: string
    """
    pass

def list_tags(ResourceIdList=None, NextToken=None):
    """
    :param ResourceIdList: [REQUIRED]
            Specifies a list of trail ARNs whose tags will be listed. The list has a limit of 20 ARNs. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            (string) --
            
    :type ResourceIdList: list
    :param NextToken: Reserved for future use.
    :type NextToken: string
    """
    pass

def lookup_events(LookupAttributes=None, StartTime=None, EndTime=None, MaxResults=None, NextToken=None):
    """
    :param LookupAttributes: Contains a list of lookup attributes. Currently the list can contain only one item.
            (dict) --Specifies an attribute and value that filter the events returned.
            AttributeKey (string) -- [REQUIRED]Specifies an attribute on which to filter the events returned.
            AttributeValue (string) -- [REQUIRED]Specifies a value for the specified AttributeKey.
            
            
    :type LookupAttributes: list
    :param StartTime: Specifies that only events that occur after or at the specified time are returned. If the specified start time is after the specified end time, an error is returned.
    :type StartTime: datetime
    :param EndTime: Specifies that only events that occur before or at the specified time are returned. If the specified end time is before the specified start time, an error is returned.
    :type EndTime: datetime
    :param MaxResults: The number of events to return. Possible values are 1 through 50. The default is 10.
    :type MaxResults: integer
    :param NextToken: The token to use to get the next page of results after a previous API call. This token must be passed in with the same parameters that were specified in the the original call. For example, if the original call specified an AttributeKey of 'Username' with a value of 'root', the call with NextToken should include those same parameters.
    :type NextToken: string
    """
    pass

def remove_tags(ResourceId=None, TagsList=None):
    """
    :param ResourceId: [REQUIRED]
            Specifies the ARN of the trail from which tags should be removed. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            
    :type ResourceId: string
    :param TagsList: Specifies a list of tags to be removed.
            (dict) --A custom key-value pair associated with a resource such as a CloudTrail trail.
            Key (string) -- [REQUIRED]The key in a key-value pair. The key must be must be no longer than 128 Unicode characters. The key must be unique for the resource to which it applies.
            Value (string) --The value in a key-value pair of a tag. The value must be no longer than 256 Unicode characters.
            
            
    :type TagsList: list
    """
    pass

def start_logging(Name=None):
    """
    :param Name: [REQUIRED]
            Specifies the name or the CloudTrail ARN of the trail for which CloudTrail logs AWS API calls. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Returns the objects or data listed below if successful. Otherwise, returns an error.
            
            
    :type Name: string
    """
    pass

def stop_logging(Name=None):
    """
    :param Name: [REQUIRED]
            Specifies the name or the CloudTrail ARN of the trail for which CloudTrail will stop logging AWS API calls. The format of a trail ARN is:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Returns the objects or data listed below if successful. Otherwise, returns an error.
            
            
    :type Name: string
    """
    pass

def update_trail(Name=None, S3BucketName=None, S3KeyPrefix=None, SnsTopicName=None, IncludeGlobalServiceEvents=None, IsMultiRegionTrail=None, EnableLogFileValidation=None, CloudWatchLogsLogGroupArn=None, CloudWatchLogsRoleArn=None, KmsKeyId=None):
    """
    :param Name: [REQUIRED]
            Specifies the name of the trail or trail ARN. If Name is a trail name, the string must meet the following requirements:
            Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)
            Start with a letter or number, and end with a letter or number
            Be between 3 and 128 characters
            Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are invalid.
            Not be in IP address format (for example, 192.168.5.4)
            If Name is a trail ARN, it must be in the format:
            arn:aws:cloudtrail:us-east-1:123456789012:trail/MyTrail
            
    :type Name: string
    :param S3BucketName: Specifies the name of the Amazon S3 bucket designated for publishing log files. See Amazon S3 Bucket Naming Requirements .
    :type S3BucketName: string
    :param S3KeyPrefix: Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files . The maximum length is 200 characters.
    :type S3KeyPrefix: string
    :param SnsTopicName: Specifies the name of the Amazon SNS topic defined for notification of log file delivery. The maximum length is 256 characters.
    :type SnsTopicName: string
    :param IncludeGlobalServiceEvents: Specifies whether the trail is publishing events from global services such as IAM to the log files.
    :type IncludeGlobalServiceEvents: boolean
    :param IsMultiRegionTrail: Specifies whether the trail applies only to the current region or to all regions. The default is false. If the trail exists only in the current region and this value is set to true, shadow trails (replications of the trail) will be created in the other regions. If the trail exists in all regions and this value is set to false, the trail will remain in the region where it was created, and its shadow trails in other regions will be deleted.
    :type IsMultiRegionTrail: boolean
    :param EnableLogFileValidation: Specifies whether log file validation is enabled. The default is false.
            Note
            When you disable log file integrity validation, the chain of digest files is broken after one hour. CloudTrail will not create digest files for log files that were delivered during a period in which log file integrity validation was disabled. For example, if you enable log file integrity validation at noon on January 1, disable it at noon on January 2, and re-enable it at noon on January 10, digest files will not be created for the log files delivered from noon on January 2 to noon on January 10. The same applies whenever you stop CloudTrail logging or delete a trail.
            
    :type EnableLogFileValidation: boolean
    :param CloudWatchLogsLogGroupArn: Specifies a log group name using an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered. Not required unless you specify CloudWatchLogsRoleArn.
    :type CloudWatchLogsLogGroupArn: string
    :param CloudWatchLogsRoleArn: Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group.
    :type CloudWatchLogsRoleArn: string
    :param KmsKeyId: Specifies the KMS key ID to use to encrypt the logs delivered by CloudTrail. The value can be a an alias name prefixed by 'alias/', a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier.
            Examples:
            alias/MyAliasName
            arn:aws:kms:us-east-1:123456789012:alias/MyAliasName
            arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012
            12345678-1234-1234-1234-123456789012
            
    :type KmsKeyId: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_file_system(CreationToken=None, PerformanceMode=None):
    """
    :param CreationToken: [REQUIRED]
            String of up to 64 ASCII characters. Amazon EFS uses this to ensure idempotent creation.
            
    :type CreationToken: string
    :param PerformanceMode: The PerformanceMode of the file system. We recommend generalPurpose performance mode for most file systems. File systems using the maxIO performance mode can scale to higher levels of aggregate throughput and operations per second with a tradeoff of slightly higher latencies for most file operations. This can't be changed after the file system has been created.
    :type PerformanceMode: string
    """
    pass

def create_mount_target(FileSystemId=None, SubnetId=None, IpAddress=None, SecurityGroups=None):
    """
    :param FileSystemId: [REQUIRED]
            ID of the file system for which to create the mount target.
            
    :type FileSystemId: string
    :param SubnetId: [REQUIRED]
            ID of the subnet to add the mount target in.
            
    :type SubnetId: string
    :param IpAddress: Valid IPv4 address within the address range of the specified subnet.
    :type IpAddress: string
    :param SecurityGroups: Up to five VPC security group IDs, of the form sg-xxxxxxxx . These must be for the same VPC as subnet specified.
            (string) --
            
    :type SecurityGroups: list
    """
    pass

def create_tags(FileSystemId=None, Tags=None):
    """
    :param FileSystemId: [REQUIRED]
            ID of the file system whose tags you want to modify (String). This operation modifies the tags only, not the file system.
            
    :type FileSystemId: string
    :param Tags: [REQUIRED]
            Array of Tag objects to add. Each Tag object is a key-value pair.
            (dict) --A tag is a key-value pair. Allowed characters: letters, whitespace, and numbers, representable in UTF-8, and the following characters:+ - = . _ : /
            Key (string) -- [REQUIRED]Tag key (String). The key can't start with aws: .
            Value (string) -- [REQUIRED]Value of the tag key.
            
            
    :type Tags: list
    """
    pass

def delete_file_system(FileSystemId=None):
    """
    :param FileSystemId: [REQUIRED]
            ID of the file system you want to delete.
            ReturnsNone
            
    :type FileSystemId: string
    """
    pass

def delete_mount_target(MountTargetId=None):
    """
    :param MountTargetId: [REQUIRED]
            ID of the mount target to delete (String).
            ReturnsNone
            
    :type MountTargetId: string
    """
    pass

def delete_tags(FileSystemId=None, TagKeys=None):
    """
    :param FileSystemId: [REQUIRED]
            ID of the file system whose tags you want to delete (String).
            
    :type FileSystemId: string
    :param TagKeys: [REQUIRED]
            List of tag keys to delete.
            (string) --
            
    :type TagKeys: list
    """
    pass

def describe_file_systems(MaxItems=None, Marker=None, CreationToken=None, FileSystemId=None):
    """
    :param MaxItems: (Optional) Specifies the maximum number of file systems to return in the response (integer). This parameter value must be greater than 0. The number of items that Amazon EFS returns is the minimum of the MaxItems parameter specified in the request and the service's internal maximum number of items per page.
    :type MaxItems: integer
    :param Marker: (Optional) Opaque pagination token returned from a previous DescribeFileSystems operation (String). If present, specifies to continue the list from where the returning call had left off.
    :type Marker: string
    :param CreationToken: (Optional) Restricts the list to the file system with this creation token (String). You specify a creation token when you create an Amazon EFS file system.
    :type CreationToken: string
    :param FileSystemId: (Optional) ID of the file system whose description you want to retrieve (String).
    :type FileSystemId: string
    """
    pass

def describe_mount_target_security_groups(MountTargetId=None):
    """
    :param MountTargetId: [REQUIRED]
            ID of the mount target whose security groups you want to retrieve.
            Return typedict
            ReturnsResponse Syntax{
              'SecurityGroups': [
                'string',
              ]
            }
            Response Structure
            (dict) --
            SecurityGroups (list) --Array of security groups.
            (string) --
            
            
    :type MountTargetId: string
    """
    pass

def describe_mount_targets(MaxItems=None, Marker=None, FileSystemId=None, MountTargetId=None):
    """
    :param MaxItems: (Optional) Maximum number of mount targets to return in the response. It must be an integer with a value greater than zero.
    :type MaxItems: integer
    :param Marker: (Optional) Opaque pagination token returned from a previous DescribeMountTargets operation (String). If present, it specifies to continue the list from where the previous returning call left off.
    :type Marker: string
    :param FileSystemId: (Optional) ID of the file system whose mount targets you want to list (String). It must be included in your request if MountTargetId is not included.
    :type FileSystemId: string
    :param MountTargetId: (Optional) ID of the mount target that you want to have described (String). It must be included in your request if FileSystemId is not included.
    :type MountTargetId: string
    """
    pass

def describe_tags(MaxItems=None, Marker=None, FileSystemId=None):
    """
    :param MaxItems: (Optional) Maximum number of file system tags to return in the response. It must be an integer with a value greater than zero.
    :type MaxItems: integer
    :param Marker: (Optional) Opaque pagination token returned from a previous DescribeTags operation (String). If present, it specifies to continue the list from where the previous call left off.
    :type Marker: string
    :param FileSystemId: [REQUIRED]
            ID of the file system whose tag set you want to retrieve.
            
    :type FileSystemId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def modify_mount_target_security_groups(MountTargetId=None, SecurityGroups=None):
    """
    :param MountTargetId: [REQUIRED]
            ID of the mount target whose security groups you want to modify.
            
    :type MountTargetId: string
    :param SecurityGroups: Array of up to five VPC security group IDs.
            (string) --
            
    :type SecurityGroups: list
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_alias(Name=None, Description=None, RoutingStrategy=None):
    """
    :param Name: [REQUIRED]
            Descriptive label associated with an alias. Alias names do not need to be unique.
            
    :type Name: string
    :param Description: Human-readable description of an alias.
    :type Description: string
    :param RoutingStrategy: [REQUIRED]
            Object specifying the fleet and routing type to use for the alias.
            Type (string) --Type of routing strategy.
            Possible routing types include the following:
            SIMPLE   The alias resolves to one specific fleet. Use this type when routing to active fleets.
            TERMINAL   The alias does not resolve to a fleet but instead can be used to display a message to the user. A terminal alias throws a TerminalRoutingStrategyException with the RoutingStrategy message embedded.
            FleetId (string) --Unique identifier for a fleet.
            Message (string) --Message text to be used with a terminal routing strategy.
            
    :type RoutingStrategy: dict
    """
    pass

def create_build(Name=None, Version=None, StorageLocation=None, OperatingSystem=None):
    """
    :param Name: Descriptive label associated with a build. Build names do not need to be unique. A build name can be changed later using `` UpdateBuild `` .
    :type Name: string
    :param Version: Version associated with this build. Version strings do not need to be unique to a build. A build version can be changed later using `` UpdateBuild `` .
    :type Version: string
    :param StorageLocation: Location in Amazon Simple Storage Service (Amazon S3) where a build's files are stored. This location is assigned in response to a CreateBuild call, and is always in the same region as the service used to create the build. For more details see the Amazon S3 documentation .
            Bucket (string) --Amazon S3 bucket identifier.
            Key (string) --Amazon S3 bucket key.
            RoleArn (string) --Amazon resource number for the cross-account access role that allows GameLift access to the S3 bucket.
            
    :type StorageLocation: dict
    :param OperatingSystem: Operating system that the game server binaries are built to run on. This value determines the type of fleet resources that you can use for this build.
    :type OperatingSystem: string
    """
    pass

def create_fleet(Name=None, Description=None, BuildId=None, ServerLaunchPath=None, ServerLaunchParameters=None, LogPaths=None, EC2InstanceType=None, EC2InboundPermissions=None, NewGameSessionProtectionPolicy=None, RuntimeConfiguration=None, ResourceCreationLimitPolicy=None):
    """
    :param Name: [REQUIRED]
            Descriptive label associated with a fleet. Fleet names do not need to be unique.
            
    :type Name: string
    :param Description: Human-readable description of a fleet.
    :type Description: string
    :param BuildId: [REQUIRED]
            Unique identifier of the build to be deployed on the new fleet. The build must have been successfully uploaded to GameLift and be in a READY status. This fleet setting cannot be changed once the fleet is created.
            
    :type BuildId: string
    :param ServerLaunchPath: This parameter is no longer used. Instead, specify a server launch path using the RuntimeConfiguration parameter. (Requests that specify a server launch path and launch parameters instead of a runtime configuration will continue to work.)
    :type ServerLaunchPath: string
    :param ServerLaunchParameters: This parameter is no longer used. Instead, specify server launch parameters in the RuntimeConfiguration parameter. (Requests that specify a server launch path and launch parameters instead of a runtime configuration will continue to work.)
    :type ServerLaunchParameters: string
    :param LogPaths: Location of default log files. When a server process is shut down, Amazon GameLift captures and stores any log files in this location. These logs are in addition to game session logs; see more on game session logs in the Amazon GameLift Developer Guide . If no default log path for a fleet is specified, GameLift will automatically upload logs stored on each instance at C:\game\logs . Use the GameLift console to access stored logs.
            (string) --
            
    :type LogPaths: list
    :param EC2InstanceType: [REQUIRED]
            Name of an EC2 instance type that is supported in Amazon GameLift. A fleet instance type determines the computing resources of each instance in the fleet, including CPU, memory, storage, and networking capacity. GameLift supports the following EC2 instance types. See Amazon EC2 Instance Types for detailed descriptions.
            
    :type EC2InstanceType: string
    :param EC2InboundPermissions: Range of IP addresses and port settings that permit inbound traffic to access server processes running on the fleet. If no inbound permissions are set, including both IP address range and port range, the server processes in the fleet cannot accept connections. You can specify one or more sets of permissions for a fleet.
            (dict) --A range of IP addresses and port settings that allow inbound traffic to connect to server processes on GameLift. Each game session hosted on a fleet is assigned a unique combination of IP address and port number, which must fall into the fleet's allowed ranges. This combination is included in the GameSession object.
            FromPort (integer) -- [REQUIRED]Starting value for a range of allowed port numbers.
            ToPort (integer) -- [REQUIRED]Ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort .
            IpRange (string) -- [REQUIRED]Range of allowed IP addresses. This value must be expressed in CIDR notation . Example: '000.000.000.000/[subnet mask] ' or optionally the shortened version '0.0.0.0/[subnet mask] '.
            Protocol (string) -- [REQUIRED]Network communication protocol used by the fleet.
            
            
    :type EC2InboundPermissions: list
    :param NewGameSessionProtectionPolicy: Game session protection policy to apply to all instances in this fleet. If this parameter is not set, instances in this fleet default to no protection. You can change a fleet's protection policy using UpdateFleetAttributes, but this change will only affect sessions created after the policy change. You can also set protection for individual instances using UpdateGameSession .
            NoProtection   The game session can be terminated during a scale-down event.
            FullProtection   If the game session is in an ACTIVE status, it cannot be terminated during a scale-down event.
            
    :type NewGameSessionProtectionPolicy: string
    :param RuntimeConfiguration: Instructions for launching server processes on each instance in the fleet. The runtime configuration for a fleet has a collection of server process configurations, one for each type of server process to run on an instance. A server process configuration specifies the location of the server executable, launch parameters, and the number of concurrent processes with that configuration to maintain on each instance. A CreateFleet request must include a runtime configuration with at least one server process configuration; otherwise the request will fail with an invalid request exception. (This parameter replaces the parameters ServerLaunchPath and ServerLaunchParameters ; requests that contain values for these parameters instead of a runtime configuration will continue to work.)
            ServerProcesses (list) --Collection of server process configurations describing what server processes to run on each instance in a fleet
            (dict) --A set of instructions for launching server processes on each instance in a fleet. Each instruction set identifies the location of the server executable, optional launch parameters, and the number of server processes with this configuration to maintain concurrently on the instance. Server process configurations make up a fleet's `` RuntimeConfiguration `` .
            LaunchPath (string) -- [REQUIRED]Location in the game build of the server executable. All game builds are installed on instances at the root C:\game\... , so an executable file located at MyGame\latest\server.exe has a launch path of 'C:\game\MyGame\latest\server.exe '.
            Parameters (string) --Optional list of parameters to pass to the server executable on launch.
            ConcurrentExecutions (integer) -- [REQUIRED]Number of server processes using this configuration to run concurrently on an instance.
            
            
    :type RuntimeConfiguration: dict
    :param ResourceCreationLimitPolicy: Policy that limits the number of game sessions an individual player can create over a span of time for this fleet.
            NewGameSessionsPerCreator (integer) --Maximum number of game sessions an individual can create during the policy period.
            PolicyPeriodInMinutes (integer) --Time span used to evaluate the resource creation limit policy.
            
    :type ResourceCreationLimitPolicy: dict
    """
    pass

def create_game_session(FleetId=None, AliasId=None, MaximumPlayerSessionCount=None, Name=None, GameProperties=None, CreatorId=None, GameSessionId=None):
    """
    :param FleetId: Unique identifier for a fleet. Each request must reference either a fleet ID or alias ID, but not both.
    :type FleetId: string
    :param AliasId: Unique identifier for a fleet alias. Each request must reference either a fleet ID or alias ID, but not both.
    :type AliasId: string
    :param MaximumPlayerSessionCount: [REQUIRED]
            Maximum number of players that can be connected simultaneously to the game session.
            
    :type MaximumPlayerSessionCount: integer
    :param Name: Descriptive label associated with a game session. Session names do not need to be unique.
    :type Name: string
    :param GameProperties: Set of properties used to administer a game session. These properties are passed to the server process hosting it.
            (dict) --Set of key-value pairs containing information a server process requires to set up a game session. This object allows you to pass in any set of data needed for your game. For more information, see the Amazon GameLift Developer Guide .
            Key (string) -- [REQUIRED]TBD
            Value (string) -- [REQUIRED]TBD
            
            
    :type GameProperties: list
    :param CreatorId: Player ID identifying the person or entity creating the game session. This ID is used to enforce a resource protection policy (if one exists) that limits the number of concurrent active game sessions one player can have.
    :type CreatorId: string
    :param GameSessionId: Custom string to include in the game session ID, with a maximum length of 48 characters. If this parameter is set, GameLift creates a game session ID in the following format: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/custom ID string'. For example, this full game session ID: 'arn:aws:gamelift:us-west-2::gamesession/fleet-2ec2aae5-c2c7-43ca-b19d-8249fe5fddf2/my-game-session' includes the custom ID string 'my-game-session'. If this parameter is not set, GameLift creates a game session ID in the same format with an auto-generated ID string.
    :type GameSessionId: string
    """
    pass

def create_player_session(GameSessionId=None, PlayerId=None):
    """
    :param GameSessionId: [REQUIRED]
            Unique identifier for the game session to add a player to. Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
            
    :type GameSessionId: string
    :param PlayerId: [REQUIRED]
            Unique identifier for the player to be added.
            
    :type PlayerId: string
    """
    pass

def create_player_sessions(GameSessionId=None, PlayerIds=None):
    """
    :param GameSessionId: [REQUIRED]
            Unique identifier for the game session to add players to. Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
            
    :type GameSessionId: string
    :param PlayerIds: [REQUIRED]
            List of unique identifiers for the players to be added.
            (string) --
            
    :type PlayerIds: list
    """
    pass

def delete_alias(AliasId=None):
    """
    :param AliasId: [REQUIRED]
            Unique identifier for a fleet alias. Specify the alias you want to delete.
            ReturnsNone
            
    :type AliasId: string
    """
    pass

def delete_build(BuildId=None):
    """
    :param BuildId: [REQUIRED]
            Unique identifier for the build you want to delete.
            ReturnsNone
            
    :type BuildId: string
    """
    pass

def delete_fleet(FleetId=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for the fleet you want to delete.
            ReturnsNone
            
    :type FleetId: string
    """
    pass

def delete_scaling_policy(Name=None, FleetId=None):
    """
    :param Name: [REQUIRED]
            Descriptive label associated with a scaling policy. Policy names do not need to be unique.
            
    :type Name: string
    :param FleetId: [REQUIRED]
            Unique identifier for a fleet.
            
    :type FleetId: string
    """
    pass

def describe_alias(AliasId=None):
    """
    :param AliasId: [REQUIRED]
            Unique identifier for a fleet alias. Specify the alias you want to retrieve.
            Return typedict
            ReturnsResponse Syntax{
              'Alias': {
                'AliasId': 'string',
                'Name': 'string',
                'Description': 'string',
                'RoutingStrategy': {
                  'Type': 'SIMPLE'|'TERMINAL',
                  'FleetId': 'string',
                  'Message': 'string'
                },
                'CreationTime': datetime(2015, 1, 1),
                'LastUpdatedTime': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            Alias (dict) --Object containing the requested alias.
            AliasId (string) --Unique identifier for a fleet alias.
            Name (string) --Descriptive label associated with an alias. Alias names do not need to be unique.
            Description (string) --Human-readable description of an alias.
            RoutingStrategy (dict) --Routing configuration for a fleet alias.
            Type (string) --Type of routing strategy.
            Possible routing types include the following:
            SIMPLE   The alias resolves to one specific fleet. Use this type when routing to active fleets.
            TERMINAL   The alias does not resolve to a fleet but instead can be used to display a message to the user. A terminal alias throws a TerminalRoutingStrategyException with the RoutingStrategy message embedded.
            FleetId (string) --Unique identifier for a fleet.
            Message (string) --Message text to be used with a terminal routing strategy.
            CreationTime (datetime) --Time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (ex: '1469498468.057'.
            LastUpdatedTime (datetime) --Time stamp indicating when this data object was last modified. Format is a number expressed in Unix time as milliseconds (ex: '1469498468.057'.
            
            
            
    :type AliasId: string
    """
    pass

def describe_build(BuildId=None):
    """
    :param BuildId: [REQUIRED]
            Unique identifier of the build that you want to retrieve properties for.
            Return typedict
            ReturnsResponse Syntax{
              'Build': {
                'BuildId': 'string',
                'Name': 'string',
                'Version': 'string',
                'Status': 'INITIALIZED'|'READY'|'FAILED',
                'SizeOnDisk': 123,
                'OperatingSystem': 'WINDOWS_2012'|'AMAZON_LINUX',
                'CreationTime': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            Build (dict) --Set of properties describing the requested build.
            BuildId (string) --Unique identifier for a build.
            Name (string) --Descriptive label associated with a build. Build names do not need to be unique. It can be set using CreateBuild or UpdateBuild .
            Version (string) --Version associated with this build. Version strings do not need to be unique to a build. This value can be set using CreateBuild or UpdateBuild .
            Status (string) --Current status of the build.
            Possible build statuses include the following:
            INITIALIZED   A new build has been defined, but no files have been uploaded. You cannot create fleets for builds that are in this status. When a build is successfully created, the build status is set to this value.
            READY   The game build has been successfully uploaded. You can now create new fleets for this build.
            FAILED   The game build upload failed. You cannot create new fleets for this build.
            SizeOnDisk (integer) --File size of the uploaded game build, expressed in bytes. When the build status is INITIALIZED , this value is 0.
            OperatingSystem (string) --Operating system that the game server binaries are built to run on. This value determines the type of fleet resources that you can use for this build.
            CreationTime (datetime) --Time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (ex: '1469498468.057'.
            
            
            
    :type BuildId: string
    """
    pass

def describe_ec2_instance_limits(EC2InstanceType=None):
    """
    :param EC2InstanceType: Name of an EC2 instance type that is supported in Amazon GameLift. A fleet instance type determines the computing resources of each instance in the fleet, including CPU, memory, storage, and networking capacity. GameLift supports the following EC2 instance types. See Amazon EC2 Instance Types for detailed descriptions. Leave this parameter blank to retrieve limits for all types.
            Return typedict
            ReturnsResponse Syntax{
              'EC2InstanceLimits': [
                {
                  'EC2InstanceType': 't2.micro'|'t2.small'|'t2.medium'|'t2.large'|'c3.large'|'c3.xlarge'|'c3.2xlarge'|'c3.4xlarge'|'c3.8xlarge'|'c4.large'|'c4.xlarge'|'c4.2xlarge'|'c4.4xlarge'|'c4.8xlarge'|'r3.large'|'r3.xlarge'|'r3.2xlarge'|'r3.4xlarge'|'r3.8xlarge'|'m3.medium'|'m3.large'|'m3.xlarge'|'m3.2xlarge'|'m4.large'|'m4.xlarge'|'m4.2xlarge'|'m4.4xlarge'|'m4.10xlarge',
                  'CurrentInstances': 123,
                  'InstanceLimit': 123
                },
              ]
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            EC2InstanceLimits (list) --Object containing the maximum number of instances for the specified instance type.
            (dict) --Maximum number of instances allowed based on the Amazon Elastic Compute Cloud (Amazon EC2) instance type. Instance limits can be retrieved by calling DescribeEC2InstanceLimits .
            EC2InstanceType (string) --Name of an EC2 instance type that is supported in Amazon GameLift. A fleet instance type determines the computing resources of each instance in the fleet, including CPU, memory, storage, and networking capacity. GameLift supports the following EC2 instance types. See Amazon EC2 Instance Types for detailed descriptions.
            CurrentInstances (integer) --Number of instances of the specified type that are currently in use by this AWS account.
            InstanceLimit (integer) --Number of instances allowed.
            
            
            
    :type EC2InstanceType: string
    """
    pass

def describe_fleet_attributes(FleetIds=None, Limit=None, NextToken=None):
    """
    :param FleetIds: Unique identifiers for the fleet(s) that you want to retrieve attributes for. To request attributes for all fleets, leave this parameter empty.
            (string) --
            
    :type FleetIds: list
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs.
    :type NextToken: string
    """
    pass

def describe_fleet_capacity(FleetIds=None, Limit=None, NextToken=None):
    """
    :param FleetIds: Unique identifier for the fleet(s) you want to retrieve capacity information for. To request capacity information for all fleets, leave this parameter empty.
            (string) --
            
    :type FleetIds: list
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs.
    :type NextToken: string
    """
    pass

def describe_fleet_events(FleetId=None, StartTime=None, EndTime=None, Limit=None, NextToken=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for the fleet to get event logs for.
            
    :type FleetId: string
    :param StartTime: Earliest date to retrieve event logs for. If no start time is specified, this call returns entries starting from when the fleet was created to the specified end time. Format is a number expressed in Unix time as milliseconds (ex: '1469498468.057'.
    :type StartTime: datetime
    :param EndTime: Most recent date to retrieve event logs for. If no end time is specified, this call returns entries from the specified start time up to the present. Format is a number expressed in Unix time as milliseconds (ex: '1469498468.057'.
    :type EndTime: datetime
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def describe_fleet_port_settings(FleetId=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for the fleet you want to retrieve port settings for.
            Return typedict
            ReturnsResponse Syntax{
              'InboundPermissions': [
                {
                  'FromPort': 123,
                  'ToPort': 123,
                  'IpRange': 'string',
                  'Protocol': 'TCP'|'UDP'
                },
              ]
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            InboundPermissions (list) --Object containing port settings for the requested fleet ID.
            (dict) --A range of IP addresses and port settings that allow inbound traffic to connect to server processes on GameLift. Each game session hosted on a fleet is assigned a unique combination of IP address and port number, which must fall into the fleet's allowed ranges. This combination is included in the GameSession object.
            FromPort (integer) --Starting value for a range of allowed port numbers.
            ToPort (integer) --Ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort .
            IpRange (string) --Range of allowed IP addresses. This value must be expressed in CIDR notation . Example: '000.000.000.000/[subnet mask] ' or optionally the shortened version '0.0.0.0/[subnet mask] '.
            Protocol (string) --Network communication protocol used by the fleet.
            
            
            
    :type FleetId: string
    """
    pass

def describe_fleet_utilization(FleetIds=None, Limit=None, NextToken=None):
    """
    :param FleetIds: Unique identifier for the fleet(s) you want to retrieve utilization data for. To request utilization data for all fleets, leave this parameter empty.
            (string) --
            
    :type FleetIds: list
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs.
    :type NextToken: string
    """
    pass

def describe_game_session_details(FleetId=None, GameSessionId=None, AliasId=None, StatusFilter=None, Limit=None, NextToken=None):
    """
    :param FleetId: Unique identifier for a fleet. Specify a fleet to retrieve information on all game sessions active on the fleet.
    :type FleetId: string
    :param GameSessionId: Unique identifier for the game session to retrieve information on. Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
    :type GameSessionId: string
    :param AliasId: Unique identifier for a fleet alias. Specify an alias to retrieve information on all game sessions active on the fleet.
    :type AliasId: string
    :param StatusFilter: Game session status to filter results on. Possible game session statuses include ACTIVE, TERMINATED , ACTIVATING and TERMINATING (the last two are transitory).
    :type StatusFilter: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def describe_game_sessions(FleetId=None, GameSessionId=None, AliasId=None, StatusFilter=None, Limit=None, NextToken=None):
    """
    :param FleetId: Unique identifier for a fleet. Specify a fleet to retrieve information on all game sessions active on the fleet.
    :type FleetId: string
    :param GameSessionId: Unique identifier for the game session to retrieve information on. Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
    :type GameSessionId: string
    :param AliasId: Unique identifier for a fleet alias. Specify an alias to retrieve information on all game sessions active on the fleet.
    :type AliasId: string
    :param StatusFilter: Game session status to filter results on. Possible game session statuses include ACTIVE , TERMINATED , ACTIVATING , and TERMINATING (the last two are transitory).
    :type StatusFilter: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def describe_instances(FleetId=None, InstanceId=None, Limit=None, NextToken=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for a fleet. Specify the fleet to retrieve instance information for.
            
    :type FleetId: string
    :param InstanceId: Unique identifier for an instance. Specify an instance to retrieve information for or leave blank to get information on all instances in the fleet.
    :type InstanceId: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def describe_player_sessions(GameSessionId=None, PlayerId=None, PlayerSessionId=None, PlayerSessionStatusFilter=None, Limit=None, NextToken=None):
    """
    :param GameSessionId: Unique identifier for the game session to get player sessions for.Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
    :type GameSessionId: string
    :param PlayerId: Unique identifier for a player.
    :type PlayerId: string
    :param PlayerSessionId: Unique identifier for a player session.
    :type PlayerSessionId: string
    :param PlayerSessionStatusFilter: Player session status to filter results on.
            Possible player session statuses include the following:
            RESERVED   The player session request has been received, but the player has not yet connected to the server process and/or been validated.
            ACTIVE   The player has been validated by the server process and is currently connected.
            COMPLETED   The player connection has been dropped.
            TIMEDOUT   A player session request was received, but the player did not connect and/or was not validated within the time-out limit (60 seconds).
            
    :type PlayerSessionStatusFilter: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. If a player session ID is specified, this parameter is ignored.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value. If a player session ID is specified, this parameter is ignored.
    :type NextToken: string
    """
    pass

def describe_runtime_configuration(FleetId=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier of the fleet to get the runtime configuration for.
            Return typedict
            ReturnsResponse Syntax{
              'RuntimeConfiguration': {
                'ServerProcesses': [
                  {
                    'LaunchPath': 'string',
                    'Parameters': 'string',
                    'ConcurrentExecutions': 123
                  },
                ]
              }
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            RuntimeConfiguration (dict) --Instructions describing how server processes should be launched and maintained on each instance in the fleet.
            ServerProcesses (list) --Collection of server process configurations describing what server processes to run on each instance in a fleet
            (dict) --A set of instructions for launching server processes on each instance in a fleet. Each instruction set identifies the location of the server executable, optional launch parameters, and the number of server processes with this configuration to maintain concurrently on the instance. Server process configurations make up a fleet's `` RuntimeConfiguration `` .
            LaunchPath (string) --Location in the game build of the server executable. All game builds are installed on instances at the root C:\game\... , so an executable file located at MyGame\latest\server.exe has a launch path of 'C:\game\MyGame\latest\server.exe '.
            Parameters (string) --Optional list of parameters to pass to the server executable on launch.
            ConcurrentExecutions (integer) --Number of server processes using this configuration to run concurrently on an instance.
            
            
            
            
    :type FleetId: string
    """
    pass

def describe_scaling_policies(FleetId=None, StatusFilter=None, Limit=None, NextToken=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for a fleet. Specify the fleet to retrieve scaling policies for.
            
    :type FleetId: string
    :param StatusFilter: Scaling policy status to filter results on. A scaling policy is only in force when in an ACTIVE status.
            ACTIVE   The scaling policy is currently in force.
            UPDATEREQUESTED   A request to update the scaling policy has been received.
            UPDATING   A change is being made to the scaling policy.
            DELETEREQUESTED   A request to delete the scaling policy has been received.
            DELETING   The scaling policy is being deleted.
            DELETED   The scaling policy has been deleted.
            ERROR   An error occurred in creating the policy. It should be removed and recreated.
            
    :type StatusFilter: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_game_session_log_url(GameSessionId=None):
    """
    :param GameSessionId: [REQUIRED]
            Unique identifier for the game session to get logs for. Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
            Return typedict
            ReturnsResponse Syntax{
              'PreSignedUrl': 'string'
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            PreSignedUrl (string) --Location of the requested game session logs, available for download.
            
            
    :type GameSessionId: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_aliases(RoutingStrategyType=None, Name=None, Limit=None, NextToken=None):
    """
    :param RoutingStrategyType: Type of routing to filter results on. Use this parameter to retrieve only aliases of a certain type. To retrieve all aliases, leave this parameter empty.
            Possible routing types include the following:
            SIMPLE   The alias resolves to one specific fleet. Use this type when routing to active fleets.
            TERMINAL   The alias does not resolve to a fleet but instead can be used to display a message to the user. A terminal alias throws a TerminalRoutingStrategyException with the RoutingStrategy message embedded.
            
    :type RoutingStrategyType: string
    :param Name: Descriptive label associated with an alias. Alias names do not need to be unique.
    :type Name: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def list_builds(Status=None, Limit=None, NextToken=None):
    """
    :param Status: Build status to filter results by. To retrieve all builds, leave this parameter empty.
            Possible build statuses include the following:
            INITIALIZED   A new build has been defined, but no files have been uploaded. You cannot create fleets for builds that are in this status. When a build is successfully created, the build status is set to this value.
            READY   The game build has been successfully uploaded. You can now create new fleets for this build.
            FAILED   The game build upload failed. You cannot create new fleets for this build.
            
    :type Status: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def list_fleets(BuildId=None, Limit=None, NextToken=None):
    """
    :param BuildId: Unique identifier of the build to return fleets for. Use this parameter to return only fleets using the specified build. To retrieve all fleets, leave this parameter empty.
    :type BuildId: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def put_scaling_policy(Name=None, FleetId=None, ScalingAdjustment=None, ScalingAdjustmentType=None, Threshold=None, ComparisonOperator=None, EvaluationPeriods=None, MetricName=None):
    """
    :param Name: [REQUIRED]
            Descriptive label associated with a scaling policy. Policy names do not need to be unique. A fleet can have only one scaling policy with the same name.
            
    :type Name: string
    :param FleetId: [REQUIRED]
            Unique identity for the fleet to scale with this policy.
            
    :type FleetId: string
    :param ScalingAdjustment: [REQUIRED]
            Amount of adjustment to make, based on the scaling adjustment type.
            
    :type ScalingAdjustment: integer
    :param ScalingAdjustmentType: [REQUIRED]
            Type of adjustment to make to a fleet's instance count (see FleetCapacity ):
            ChangeInCapacity   add (or subtract) the scaling adjustment value from the current instance count. Positive values scale up while negative values scale down.
            ExactCapacity   set the instance count to the scaling adjustment value.
            PercentChangeInCapacity   increase or reduce the current instance count by the scaling adjustment, read as a percentage. Positive values scale up while negative values scale down; for example, a value of '-10' scales the fleet down by 10%.
            
    :type ScalingAdjustmentType: string
    :param Threshold: [REQUIRED]
            Metric value used to trigger a scaling event.
            
    :type Threshold: float
    :param ComparisonOperator: [REQUIRED]
            Comparison operator to use when measuring the metric against the threshold value.
            
    :type ComparisonOperator: string
    :param EvaluationPeriods: [REQUIRED]
            Length of time (in minutes) the metric must be at or beyond the threshold before a scaling event is triggered.
            
    :type EvaluationPeriods: integer
    :param MetricName: [REQUIRED]
            Name of the Amazon GameLift-defined metric that is used to trigger an adjustment.
            ActivatingGameSessions   number of game sessions in the process of being created (game session status = ACTIVATING ).
            ActiveGameSessions   number of game sessions currently running (game session status = ACTIVE ).
            CurrentPlayerSessions   number of active or reserved player sessions (player session status = ACTIVE or RESERVED ).
            AvailablePlayerSessions   number of player session slots currently available in active game sessions across the fleet, calculated by subtracting a game session's current player session count from its maximum player session count. This number includes game sessions that are not currently accepting players (game session PlayerSessionCreationPolicy = DENY_ALL ).
            ActiveInstances   number of instances currently running a game session.
            IdleInstances   number of instances not currently running a game session.
            
    :type MetricName: string
    """
    pass

def request_upload_credentials(BuildId=None):
    """
    :param BuildId: [REQUIRED]
            Unique identifier for the build you want to get credentials for.
            Return typedict
            ReturnsResponse Syntax{
              'UploadCredentials': {
                'AccessKeyId': 'string',
                'SecretAccessKey': 'string',
                'SessionToken': 'string'
              },
              'StorageLocation': {
                'Bucket': 'string',
                'Key': 'string',
                'RoleArn': 'string'
              }
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            UploadCredentials (dict) --AWS credentials required when uploading a game build to the storage location. These credentials have a limited lifespan and are valid only for the build they were issued for.
            AccessKeyId (string) --Access key for an AWS account.
            SecretAccessKey (string) --Secret key for an AWS account.
            SessionToken (string) --Token specific to a build ID.
            StorageLocation (dict) --Amazon S3 path and key, identifying where the game build files are stored.
            Bucket (string) --Amazon S3 bucket identifier.
            Key (string) --Amazon S3 bucket key.
            RoleArn (string) --Amazon resource number for the cross-account access role that allows GameLift access to the S3 bucket.
            
            
            
    :type BuildId: string
    """
    pass

def resolve_alias(AliasId=None):
    """
    :param AliasId: [REQUIRED]
            Unique identifier for the alias you want to resolve.
            Return typedict
            ReturnsResponse Syntax{
              'FleetId': 'string'
            }
            Response Structure
            (dict) --Represents the returned data in response to a request action.
            FleetId (string) --Fleet ID associated with the requested alias.
            
            
    :type AliasId: string
    """
    pass

def search_game_sessions(FleetId=None, AliasId=None, FilterExpression=None, SortExpression=None, Limit=None, NextToken=None):
    """
    :param FleetId: Unique identifier for a fleet. Each request must reference either a fleet ID or alias ID, but not both.
    :type FleetId: string
    :param AliasId: Unique identifier for a fleet alias. Each request must reference either a fleet ID or alias ID, but not both.
    :type AliasId: string
    :param FilterExpression: String containing the search criteria for the session search. If no filter expression is included, the request returns results for all game sessions in the fleet that are in ACTIVE status.
            A filter expression can contain one or multiple conditions. Each condition consists of the following:
            Operand -- Name of a game session attribute. Valid values are gameSessionName , gameSessionId , creationTimeMillis , playerSessionCount , maximumSessions , hasAvailablePlayerSessions .
            Comparator -- Valid comparators are: = , ```` , ```` , ```` , = , = .
            Value -- Value to be searched for. Values can be numbers, boolean values (true/false) or strings. String values are case sensitive, enclosed in single quotes. Special characters must be escaped. Boolean and string values can only be used with the comparators = and ```` . For example, the following filter expression searches on gameSessionName : 'FilterExpression': 'gameSessionName = 'Matt\\'s Awesome Game 1'' .
            To chain multiple conditions in a single expression, use the logical keywords AND , OR , and NOT and parentheses as needed. For example: x AND y AND NOT z , NOT (x OR y) .
            Session search evaluates conditions from left to right using the following precedence rules:
            = , ```` , ```` , ```` , = , =
            Parentheses
            NOT
            AND
            OR
            For example, this filter expression retrieves game sessions hosting at least ten players that have an open player slot: 'maximumSessions=10 AND hasAvailablePlayerSessions=true' .
            
    :type FilterExpression: string
    :param SortExpression: Instructions on how to sort the search results. If no sort expression is included, the request returns results in random order. A sort expression consists of the following elements:
            Operand -- Name of a game session attribute. Valid values are gameSessionName , gameSessionId , creationTimeMillis , playerSessionCount , maximumSessions , hasAvailablePlayerSessions .
            Order -- Valid sort orders are ASC (ascending) and DESC (descending).
            For example, this sort expression returns the oldest active sessions first: 'SortExpression': 'creationTimeMillis ASC' . Results with a null value for the sort operand are returned at the end of the list.
            
    :type SortExpression: string
    :param Limit: Maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. The maximum number of results returned is 20, even if this value is not set or is set higher than 20.
    :type Limit: integer
    :param NextToken: Token indicating the start of the next sequential page of results. Use the token that is returned with a previous call to this action. To specify the start of the result set, do not specify a value.
    :type NextToken: string
    """
    pass

def update_alias(AliasId=None, Name=None, Description=None, RoutingStrategy=None):
    """
    :param AliasId: [REQUIRED]
            Unique identifier for a fleet alias. Specify the alias you want to update.
            
    :type AliasId: string
    :param Name: Descriptive label associated with an alias. Alias names do not need to be unique.
    :type Name: string
    :param Description: Human-readable description of an alias.
    :type Description: string
    :param RoutingStrategy: Object specifying the fleet and routing type to use for the alias.
            Type (string) --Type of routing strategy.
            Possible routing types include the following:
            SIMPLE   The alias resolves to one specific fleet. Use this type when routing to active fleets.
            TERMINAL   The alias does not resolve to a fleet but instead can be used to display a message to the user. A terminal alias throws a TerminalRoutingStrategyException with the RoutingStrategy message embedded.
            FleetId (string) --Unique identifier for a fleet.
            Message (string) --Message text to be used with a terminal routing strategy.
            
    :type RoutingStrategy: dict
    """
    pass

def update_build(BuildId=None, Name=None, Version=None):
    """
    :param BuildId: [REQUIRED]
            Unique identifier of the build you want to update.
            
    :type BuildId: string
    :param Name: Descriptive label associated with a build. Build names do not need to be unique.
    :type Name: string
    :param Version: Version associated with this build. Version strings do not need to be unique to a build.
    :type Version: string
    """
    pass

def update_fleet_attributes(FleetId=None, Name=None, Description=None, NewGameSessionProtectionPolicy=None, ResourceCreationLimitPolicy=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for the fleet you want to update attribute metadata for.
            
    :type FleetId: string
    :param Name: Descriptive label associated with a fleet. Fleet names do not need to be unique.
    :type Name: string
    :param Description: Human-readable description of a fleet.
    :type Description: string
    :param NewGameSessionProtectionPolicy: Game session protection policy to apply to all new instances created in this fleet. Instances that already exist are not affected. You can set protection for individual instances using UpdateGameSession .
            NoProtection   The game session can be terminated during a scale-down event.
            FullProtection   If the game session is in an ACTIVE status, it cannot be terminated during a scale-down event.
            
    :type NewGameSessionProtectionPolicy: string
    :param ResourceCreationLimitPolicy: Policy that limits the number of game sessions an individual player can create over a span of time.
            NewGameSessionsPerCreator (integer) --Maximum number of game sessions an individual can create during the policy period.
            PolicyPeriodInMinutes (integer) --Time span used to evaluate the resource creation limit policy.
            
    :type ResourceCreationLimitPolicy: dict
    """
    pass

def update_fleet_capacity(FleetId=None, DesiredInstances=None, MinSize=None, MaxSize=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for the fleet you want to update capacity for.
            
    :type FleetId: string
    :param DesiredInstances: Number of EC2 instances you want this fleet to host.
    :type DesiredInstances: integer
    :param MinSize: Minimum value allowed for the fleet's instance count. Default if not set is 0.
    :type MinSize: integer
    :param MaxSize: Maximum value allowed for the fleet's instance count. Default if not set is 1.
    :type MaxSize: integer
    """
    pass

def update_fleet_port_settings(FleetId=None, InboundPermissionAuthorizations=None, InboundPermissionRevocations=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier for the fleet you want to update port settings for.
            
    :type FleetId: string
    :param InboundPermissionAuthorizations: Collection of port settings to be added to the fleet record.
            (dict) --A range of IP addresses and port settings that allow inbound traffic to connect to server processes on GameLift. Each game session hosted on a fleet is assigned a unique combination of IP address and port number, which must fall into the fleet's allowed ranges. This combination is included in the GameSession object.
            FromPort (integer) -- [REQUIRED]Starting value for a range of allowed port numbers.
            ToPort (integer) -- [REQUIRED]Ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort .
            IpRange (string) -- [REQUIRED]Range of allowed IP addresses. This value must be expressed in CIDR notation . Example: '000.000.000.000/[subnet mask] ' or optionally the shortened version '0.0.0.0/[subnet mask] '.
            Protocol (string) -- [REQUIRED]Network communication protocol used by the fleet.
            
            
    :type InboundPermissionAuthorizations: list
    :param InboundPermissionRevocations: Collection of port settings to be removed from the fleet record.
            (dict) --A range of IP addresses and port settings that allow inbound traffic to connect to server processes on GameLift. Each game session hosted on a fleet is assigned a unique combination of IP address and port number, which must fall into the fleet's allowed ranges. This combination is included in the GameSession object.
            FromPort (integer) -- [REQUIRED]Starting value for a range of allowed port numbers.
            ToPort (integer) -- [REQUIRED]Ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort .
            IpRange (string) -- [REQUIRED]Range of allowed IP addresses. This value must be expressed in CIDR notation . Example: '000.000.000.000/[subnet mask] ' or optionally the shortened version '0.0.0.0/[subnet mask] '.
            Protocol (string) -- [REQUIRED]Network communication protocol used by the fleet.
            
            
    :type InboundPermissionRevocations: list
    """
    pass

def update_game_session(GameSessionId=None, MaximumPlayerSessionCount=None, Name=None, PlayerSessionCreationPolicy=None, ProtectionPolicy=None):
    """
    :param GameSessionId: [REQUIRED]
            Unique identifier for the game session to update. Game session ID format is as follows: 'arn:aws:gamelift:region::gamesession/fleet-fleet ID/ID string'. The value of ID stringis either a custom ID string (if one was specified when the game session was created) an auto-generated string.
            
    :type GameSessionId: string
    :param MaximumPlayerSessionCount: Maximum number of players that can be simultaneously connected to the game session.
    :type MaximumPlayerSessionCount: integer
    :param Name: Descriptive label associated with a game session. Session names do not need to be unique.
    :type Name: string
    :param PlayerSessionCreationPolicy: Policy determining whether or not the game session accepts new players.
    :type PlayerSessionCreationPolicy: string
    :param ProtectionPolicy: Game session protection policy to apply to this game session only.
            NoProtection   The game session can be terminated during a scale-down event.
            FullProtection   If the game session is in an ACTIVE status, it cannot be terminated during a scale-down event.
            
    :type ProtectionPolicy: string
    """
    pass

def update_runtime_configuration(FleetId=None, RuntimeConfiguration=None):
    """
    :param FleetId: [REQUIRED]
            Unique identifier of the fleet to update runtime configuration for.
            
    :type FleetId: string
    :param RuntimeConfiguration: [REQUIRED]
            Instructions for launching server processes on each instance in the fleet. The runtime configuration for a fleet has a collection of server process configurations, one for each type of server process to run on an instance. A server process configuration specifies the location of the server executable, launch parameters, and the number of concurrent processes with that configuration to maintain on each instance.
            ServerProcesses (list) --Collection of server process configurations describing what server processes to run on each instance in a fleet
            (dict) --A set of instructions for launching server processes on each instance in a fleet. Each instruction set identifies the location of the server executable, optional launch parameters, and the number of server processes with this configuration to maintain concurrently on the instance. Server process configurations make up a fleet's `` RuntimeConfiguration `` .
            LaunchPath (string) -- [REQUIRED]Location in the game build of the server executable. All game builds are installed on instances at the root C:\game\... , so an executable file located at MyGame\latest\server.exe has a launch path of 'C:\game\MyGame\latest\server.exe '.
            Parameters (string) --Optional list of parameters to pass to the server executable on launch.
            ConcurrentExecutions (integer) -- [REQUIRED]Number of server processes using this configuration to run concurrently on an instance.
            
            
    :type RuntimeConfiguration: dict
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def describe_stream(StreamArn=None, Limit=None, ExclusiveStartShardId=None):
    """
    :param StreamArn: [REQUIRED]
            The Amazon Resource Name (ARN) for the stream.
            
    :type StreamArn: string
    :param Limit: The maximum number of shard objects to return. The upper limit is 100.
    :type Limit: integer
    :param ExclusiveStartShardId: The shard ID of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedShardId in the previous operation.
    :type ExclusiveStartShardId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_records(ShardIterator=None, Limit=None):
    """
    :param ShardIterator: [REQUIRED]
            A shard iterator that was retrieved from a previous GetShardIterator operation. This iterator can be used to access the stream records in this shard.
            
    :type ShardIterator: string
    :param Limit: The maximum number of records to return from the shard. The upper limit is 1000.
    :type Limit: integer
    """
    pass

def get_shard_iterator(StreamArn=None, ShardId=None, ShardIteratorType=None, SequenceNumber=None):
    """
    :param StreamArn: [REQUIRED]
            The Amazon Resource Name (ARN) for the stream.
            
    :type StreamArn: string
    :param ShardId: [REQUIRED]
            The identifier of the shard. The iterator will be returned for this shard ID.
            
    :type ShardId: string
    :param ShardIteratorType: [REQUIRED]
            Determines how the shard iterator is used to start reading stream records from the shard:
            AT_SEQUENCE_NUMBER - Start reading exactly from the position denoted by a specific sequence number.
            AFTER_SEQUENCE_NUMBER - Start reading right after the position denoted by a specific sequence number.
            TRIM_HORIZON - Start reading at the last (untrimmed) stream record, which is the oldest record in the shard. In DynamoDB Streams, there is a 24 hour limit on data retention. Stream records whose age exceeds this limit are subject to removal (trimming) from the stream.
            LATEST - Start reading just after the most recent stream record in the shard, so that you always read the most recent data in the shard.
            
    :type ShardIteratorType: string
    :param SequenceNumber: The sequence number of a stream record in the shard from which to start reading.
    :type SequenceNumber: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_streams(TableName=None, Limit=None, ExclusiveStartStreamArn=None):
    """
    :param TableName: If this parameter is provided, then only the streams associated with this table name are returned.
    :type TableName: string
    :param Limit: The maximum number of streams to return. The upper limit is 100.
    :type Limit: integer
    :param ExclusiveStartStreamArn: The ARN (Amazon Resource Name) of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedStreamArn in the previous operation.
    :type ExclusiveStartStreamArn: string
    """
    pass

